@@ -103,7 +103,6 @@ const Application = new Lang.Class({
         this.minersRunning = [];
         this._activationTimestamp = Gdk.CURRENT_TIME;
         this._extractPriority = null;
-        this._searchProvider = null;
 
         this.isBooks = isBooks;
 
@@ -124,6 +123,10 @@ const Application = new Lang.Class({
 
         this.add_main_option('version', 'v'.charCodeAt(0), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _("Show the version of the program"), null);
+
+        this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
+        this._searchProvider.connect('activate-result', Lang.bind(this, this._onActivateResult));
+        this._searchProvider.connect('launch-search', Lang.bind(this, this._onLaunchSearch));
     },
 
     _initGettingStarted: function() {
@@ -145,7 +148,11 @@ const Application = new Lang.Class({
                 return;
             }
 
-            file.query_info_async('standard::type', Gio.FileQueryInfoFlags.NONE, 0, null, Lang.bind(this,
+            file.query_info_async(Gio.FILE_ATTRIBUTE_STANDARD_TYPE,
+                                  Gio.FileQueryInfoFlags.NONE,
+                                  GLib.PRIORITY_DEFAULT,
+                                  null,
+                                  Lang.bind(this,
                 function(object, res) {
                     try {
                         let info = object.query_info_finish(res);
@@ -441,28 +448,12 @@ const Application = new Lang.Class({
     vfunc_dbus_register: function(connection, path) {
         this.parent(connection, path);
 
-        if (this._searchProvider != null)
-            throw(new Error('ShellSearchProvider already instantiated - dbus_register called twice?'));
-
-        this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
-        this._searchProvider.connect('activate-result', Lang.bind(this, this._onActivateResult));
-        this._searchProvider.connect('launch-search', Lang.bind(this, this._onLaunchSearch));
-
-        try {
-            this._searchProvider.export(connection);
-        } catch(e) {
-            this._searchProvider = null;
-            throw(e);
-        }
-
+        this._searchProvider.export(connection);
         return true;
     },
 
     vfunc_dbus_unregister: function(connection, path) {
-        if (this._searchProvider != null) {
-            this._searchProvider.unexport(connection);
-            this._searchProvider = null;
-        }
+        this._searchProvider.unexport(connection);
 
         this.parent(connection, path);
     },
