@@ -36,7 +36,6 @@ const Zpj = imports.gi.Zpj;
 const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
-const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
 const Application = imports.application;
@@ -414,20 +413,6 @@ const DocCommon = new Lang.Class({
 
     load: function(passwd, cancellable, callback) {
         Utils.debug('Loading ' + this.__name__ + ' ' + this.id);
-
-        if (this.collection) {
-            Mainloop.idle_add(Lang.bind(this,
-                function() {
-                    let error = new GLib.Error(Gio.IOErrorEnum,
-                                               Gio.IOErrorEnum.NOT_SUPPORTED,
-                                               "Collections can't be loaded");
-                    callback(this, null, error);
-                    return GLib.SOURCE_REMOVE;
-                }));
-
-            return;
-        }
-
         this.download(true, cancellable, Lang.bind(this,
             function(fromCache, error) {
                 if (error) {
@@ -462,21 +447,18 @@ const DocCommon = new Lang.Class({
     },
 
     canEdit: function() {
-        log('Error: DocCommon implementations must override canEdit');
+        throw(new Error('DocCommon implementations must override canEdit'));
     },
 
     canShare: function() {
-        log('Error: DocCommon implementations must override canShare');
+        throw(new Error('DocCommon implementations must override canShare'));
     },
 
     canTrash: function() {
-        log('Error: DocCommon implementations must override canTrash');
+        throw(new Error('DocCommon implementations must override canTrash'));
     },
 
     canPrint: function(docModel) {
-        if (this.collection)
-            return false;
-
         if (!docModel)
             return false;
 
@@ -494,11 +476,11 @@ const DocCommon = new Lang.Class({
     },
 
     trashImpl: function() {
-        log('Error: DocCommon implementations must override trashImpl');
+        throw(new Error('DocCommon implementations must override trashImpl'));
     },
 
     createThumbnail: function(callback) {
-        log('Error: DocCommon implementations must override createThumbnail');
+        throw(new Error('DocCommon implementations must override createThumbnail'));
     },
 
     refreshIcon: function() {
@@ -519,7 +501,9 @@ const DocCommon = new Lang.Class({
 
         this._file = Gio.file_new_for_uri(this.uri);
         this._file.query_info_async(Gio.FILE_ATTRIBUTE_THUMBNAIL_PATH,
-                                    0, 0, null,
+                                    Gio.FileQueryInfoFlags.NONE,
+                                    GLib.PRIORITY_DEFAULT,
+                                    null,
                                     Lang.bind(this, this._onFileQueryInfo));
     },
 
@@ -551,7 +535,9 @@ const DocCommon = new Lang.Class({
 
         // get the new thumbnail path
         this._file.query_info_async(Gio.FILE_ATTRIBUTE_THUMBNAIL_PATH,
-                                    0, 0, null,
+                                    Gio.FileQueryInfoFlags.NONE,
+                                    GLib.PRIORITY_DEFAULT,
+                                    null,
                                     Lang.bind(this, this._onThumbnailPathInfo));
     },
 
@@ -578,34 +564,42 @@ const DocCommon = new Lang.Class({
 
         thumbFile.read_async(GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
             function(object, res) {
+                let stream;
+
                 try {
-                    let stream = object.read_finish(res);
-                    let scale = Application.application.getScaleFactor();
-                    GdkPixbuf.Pixbuf.new_from_stream_at_scale_async(stream,
-                        Utils.getIconSize() * scale, Utils.getIconSize() * scale,
-                        true, null, Lang.bind(this,
-                            function(object, res) {
-                                try {
-                                    let pixbuf = GdkPixbuf.Pixbuf.new_from_stream_finish(res);
-                                    this._setOrigPixbuf(pixbuf);
-                                } catch (e) {
-                                    if (!e.matches(GdkPixbuf.PixbufError, GdkPixbuf.PixbufError.UNKNOWN_TYPE))
-                                        logError(e, 'Unable to create pixbuf from ' + thumbFile.get_uri());
-
-                                    this._failedThumbnailing = true;
-                                    this._thumbPath = null;
-                                    thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
-                                }
-
-                                // close the underlying stream immediately
-                                stream.close_async(0, null, null);
-                            }));
+                    stream = object.read_finish(res);
                 } catch (e) {
                     logError(e, 'Unable to read file at ' + thumbFile.get_uri());
                     this._failedThumbnailing = true;
                     this._thumbPath = null;
                     thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
+                    return;
                 }
+
+                let scale = Application.application.getScaleFactor();
+                GdkPixbuf.Pixbuf.new_from_stream_at_scale_async(stream,
+                    Utils.getIconSize() * scale, Utils.getIconSize() * scale,
+                    true, null, Lang.bind(this,
+                        function(object, res) {
+                            // close the underlying stream immediately
+                            stream.close_async(0, null, null);
+
+                            let pixbuf;
+
+                            try {
+                                pixbuf = GdkPixbuf.Pixbuf.new_from_stream_finish(res);
+                            } catch (e) {
+                                if (!e.matches(GdkPixbuf.PixbufError, GdkPixbuf.PixbufError.UNKNOWN_TYPE))
+                                    logError(e, 'Unable to create pixbuf from ' + thumbFile.get_uri());
+
+                                this._failedThumbnailing = true;
+                                this._thumbPath = null;
+                                thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
+                                return;
+                            }
+
+                            this._setOrigPixbuf(pixbuf);
+                        }));
             }));
     },
 
@@ -867,7 +861,16 @@ const LocalDocument = new Lang.Class({
     createThumbnail: function(callback) {
         GdPrivate.queue_thumbnail_job_for_file_async(this._file, Lang.bind(this,
             function(object, res) {
-                let thumbnailed = GdPrivate.queue_thumbnail_job_for_file_finish(res);
+                let thumbnailed = false;
+
+                try {
+                    thumbnailed = GdPrivate.queue_thumbnail_job_for_file_finish(res);
+                } catch (e) {
+                    /* We don't care about reporting errors here, just fail the
+                     * thumbnail.
+                     */
+                }
+
                 callback(thumbnailed);
             }));
     },
@@ -883,6 +886,10 @@ const LocalDocument = new Lang.Class({
         this.typeDescription = description;
     },
 
+    downloadImpl: function(localFile, cancellable, callback) {
+        throw(new Error('LocalDocuments need not be downloaded'));
+    },
+
     load: function(passwd, cancellable, callback) {
         Utils.debug('Loading ' + this.__name__ + ' ' + this.id);
         this.loadLocal(passwd, cancellable, callback);
@@ -1167,7 +1174,16 @@ const OwncloudDocument = new Lang.Class({
     createThumbnail: function(callback) {
         GdPrivate.queue_thumbnail_job_for_file_async(this._file, Lang.bind(this,
             function(object, res) {
-                let thumbnailed = GdPrivate.queue_thumbnail_job_for_file_finish(res);
+                let thumbnailed = false;
+
+                try {
+                    thumbnailed = GdPrivate.queue_thumbnail_job_for_file_finish(res);
+                } catch (e) {
+                    /* We don't care about reporting errors here, just fail the
+                     * thumbnail.
+                     */
+                }
+
                 callback(thumbnailed);
             }));
     },
