@@ -922,7 +922,7 @@ const SelectionToolbar = new Lang.Class({
         let hasSelection = (selection.length > 0);
 
         let showTrash = hasSelection;
-        let showPrint = false;
+        let showPrint = hasSelection;
         let showProperties = hasSelection;
         let showOpen = hasSelection;
         let showShare = hasSelection;
@@ -943,21 +943,15 @@ const SelectionToolbar = new Lang.Class({
                     showShare = false;
 
                 showTrash &= doc.canTrash();
+                showPrint &= !doc.collection;
             }));
 
         showOpen = (apps.length > 0);
 
-        if (selection.length == 1) {
-            let doc = Application.documentManager.getItemById(selection[0]);
-            doc.load(null, null, Lang.bind(this,
-                function(doc, docModel, error) {
-                    showPrint = doc.canPrint(docModel);
-                    this._toolbarPrint.set_sensitive(showPrint);
-                }));
-        }
-
-        if (selection.length > 1)
+        if (selection.length > 1) {
+            showPrint = false;
             showProperties = false;
+        }
 
         let openLabel = null;
         if (apps.length == 1) {
@@ -983,7 +977,7 @@ const SelectionToolbar = new Lang.Class({
     _onToolbarCollection: function() {
         let toplevel = this.get_toplevel();
         if (!toplevel.is_toplevel())
-            return;
+            throw(new Error('Code should not be reached'));
 
         let dialog = new OrganizeCollectionDialog(toplevel);
         dialog.connect('destroy', Lang.bind(this, function() {
